=====
racpy
=====


.. image:: https://img.shields.io/pypi/v/racpy.svg
        :target: https://pypi.python.org/pypi/racpy

.. image:: https://img.shields.io/travis/reese3928/racpy.svg
        :target: https://travis-ci.com/reese3928/racpy

.. image:: https://readthedocs.org/projects/racpy/badge/?version=latest
        :target: https://racpy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/reese3928/racpy/shield.svg
     :target: https://pyup.io/repos/github/reese3928/racpy/
     :alt: Updates



RNASeq Age Calculation in Python


* Free software: MIT license
* Documentation: https://racpy.readthedocs.io.


Features
--------

* This is the Python verion of our proposed multi-tissue transcriptional age calculator.

Authors
--------

* Xu Ren <xuren2120@gmail.com>
* `Pei Fen Kuan <http://www.ams.sunysb.edu/~pfkuan/>`__ <peifen.kuan@stonybrook.edu>

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
